==> motion_4.0.orig.tar.gz: motion-release-4.0/README.md <==
Motion
=============

## Status
The build status from travis-ci for the master branch is: [![Build Status](https://travis-ci.org/Motion-Project/motion.svg?branch=master)](https://travis-ci.org/Motion-Project/motion)

## Description

Motion is a program that monitors the video signal from one or more cameras and
is able to detect if a significant part of the picture has changed. Or in other
words, it can detect motion.

## Documentation

The documentation for Motion is contained within the file motion_guide.html.

The offline version of this file is available in the **doc/motion** directory.  The 
online version of the motion_guide.html file is within the master branch and can be viewed [here](http://htmlpreview.github.com/?https://github.com/Motion-Project/motion/blob/master/motion_guide.html)

In addition to the detailed building instructions included within the guide, the 
INSTALL file contains abbreviated building instructions.

## Resources

Please join the mailing list [here](https://lists.sourceforge.net/lists/listinfo/motion-user)

We prefer support through the mailing list because more people will have the benefit from the answers.
A archive of mailing list discussions can be viewed [here](https://sourceforge.net/p/motion/mailman/motion-user/)

## License

Motion is mainly distributed under the GNU GENERAL PUBLIC LICENSE (GPL) version 2 or later.
See the copyright file for a list of all the licensing terms of the various components of Motion.

The file CREDITS lists the many people who have contributed to Motion over the years.

## Contributing

Issues and Patches should be submitted via github and include detail descriptions
of the issue being addressed as well as any documentation updates that would be
needed with the change.

==> motion_4.3.2.orig.tar.gz: motion-release-4.3.2/README.md <==
Motion
=============

## Status
The build status from travis-ci for the master branch is: [![Build Status](https://travis-ci.org/Motion-Project/motion.svg?branch=master)](https://travis-ci.org/Motion-Project/motion)

## Description

Motion is a program that monitors the video signal from one or more cameras and
is able to detect if a significant part of the picture has changed. Or in other
words, it can detect motion.

## Documentation

The documentation for Motion is contained within the file motion_guide.html.

The offline version of this file is available in the **doc/motion** directory.  The
online version of the motion_guide.html file can be viewed [here](https://motion-project.github.io/motion_guide.html)

In addition to the detailed building instructions included within the guide, the
INSTALL file contains abbreviated building instructions.

## Resources

Please join the mailing list [here](https://lists.sourceforge.net/lists/listinfo/motion-user)

We prefer support through the mailing list because more people will have the benefit from the answers.
A archive of mailing list discussions can be viewed [here](https://sourceforge.net/p/motion/mailman/motion-user/)

## License

Motion is mainly distributed under the GNU GENERAL PUBLIC LICENSE (GPL) version 2 or later.
See the copyright file for a list of all the licensing terms of the various components of Motion.

The file CREDITS lists the many people who have contributed to Motion over the years.

## Contributing

Issues and Patches should be submitted via github and include detail descriptions
of the issue being addressed as well as any documentation updates that would be
needed with the change.
